tsseg.algorithms.vsax package
=============================

Z-normalisation → PAA → SAX symbols → DP segmentation balancing fidelity and
complexity.

| **Type:** state detection
| **Supervision:** semi-supervised
| **Scope:** identical SAX words → same state label

**Implementation:** *Origin: new code.*

Submodules
----------

tsseg.algorithms.vsax.detector module
-------------------------------------

.. automodule:: tsseg.algorithms.vsax.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.vsax
   :members:
   :show-inheritance:
   :undoc-members:
